@@ -1,5 +1,7 @@
 from typing import Union
 
+from .types import *
+
 
 class UnserializeTypeError(TypeError):
     pass
@@ -9,15 +11,6 @@ class UnserializeFormatError(SyntaxError):
     pass
 
 
-class PHP_Class:
-    pass
-
-
-class __PHP_Incomplete_Class(PHP_Class):
-    def __init__(self, name: str):
-        self.__PHP_Incomplete_Class_Name = name
-
-
 def _handle_int(sg):
     s = '0'
     while s[-1] != ';' and s[-1] != ':':
@@ -57,22 +50,40 @@ def _handle_array(sg):
     return result
 
 
+def _get_attr_type(name: str):
+    if not name.startswith('\0'):
+        return 'public', name
+    end = name[1:].find('\0') + 1
+    sli, varname = name[1:end], name[end + 1:]
+    if sli == '*':
+        return 'protected', varname
+    else:
+        return 'private', (sli, varname)
+
+
 def _handle_object(sg):
     class_name = _handle_str(sg).decode('utf-8')
     property_cnt = _handle_int(sg)
     assert chr(next(sg)) == '{'
-    class_type = __PHP_Incomplete_Class
     for cls in PHP_Class.__subclasses__():
         if cls.__name__ == class_name:
-            class_type = cls
-    # __init__ not called
-    obj = PHP_Class.__new__(class_type)
+            # __init__ not called
+            obj = PHP_Class.__new__(cls)
+    else:
+        obj = __PHP_Incomplete_Class(class_name)
     for _ in range(property_cnt):
         assert chr(next(sg)) == 's' and chr(next(sg)) == ':'
         # property names must be string
-        name = _handle_str(sg).decode('utf-8')
-        value = _handle(sg)
-        setattr(obj, name, value)
+        var_type, var_name = _get_attr_type(_handle_str(sg).decode('utf-8'))
+        var_value = _handle(sg)
+        if var_type == 'public':
+            if hasattr(obj, f'{var_type}_{var_name}'):
+                var_name = f'{var_type}_{var_name}'
+        elif var_type == 'protected':
+            var_name = f'{var_type}_{var_name}'
+        elif var_type == 'private':
+            var_name = f'{var_type}_{var_name[1]}'
+        setattr(obj, var_name, var_value)
     assert chr(next(sg)) == '}'
     return obj
 
